# xeuledoc
![PyPI](https://img.shields.io/pypi/v/xeuledoc) ![PyPI - Downloads](https://static.pepy.tech/badge/xeuledoc) ![PyPI - License](https://img.shields.io/pypi/l/xeuledoc)

Fetch information about any public Google document.\
It's working on :
- Google Drive
- Google Docs
- Google Spreadsheets
- Google Slides
- Google Drawning
- Google My Maps
- Google Apps Script
- Google Jamboard

## 📈 Demo
![](https://files.catbox.moe/k5x3as.gif)

## 💡 Prerequisite
   [Python 3](https://www.python.org/downloads/release/python-370/)
## 🛠️ Installation
### With PyPI
```sh
pip3 install xeuledoc
```

### With Github
```sh
git clone https://github.com/Malfrats/xeuledoc.git
cd xeuledoc/
python3 setup.py install
```

## 📝 License
[GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.fr.html)
